==> openGion_dev_5.6.8.0.zip: opengion/uap/webapps/gf/db/oracle/sql/install/01_TABLE/GF72S.sql <==
/****************************************************************************/
/* GF72 ( 登録ﾎﾞﾀﾝ状態ﾃｰﾌﾞﾙ )                                               */
/*                                                                          */
/* Created : 2013/09/03 10:23:35                                            */
/****************************************************************************/
CREATE TABLE GF72 (
   SYSTEM_ID    VARCHAR2 (  10 )                    NOT NULL            /*  10 ｼｽﾃﾑID       */
 , TBLSYU       VARCHAR2 (   1 )                    NOT NULL            /*  20 ﾃｰﾌﾞﾙ種別    */
 , ADDRESS      VARCHAR2 ( 256 )                                        /*  30 ｱﾄﾞﾚｽ        */
 , FILENAME     VARCHAR2 (  60 )                                        /*  40 ﾌｧｲﾙ名       */
 , FILEPATH     VARCHAR2 ( 256 )                                        /*  50 ﾌｧｲﾙﾊﾟｽ      */
 , MODIFIED     VARCHAR2 (  14 )                                        /*  60 最終更新日   */
 , TAGNAME      VARCHAR2 (  30 )                                        /*  80 ﾀｸﾞ名称      */
 , TO_GAMENID   VARCHAR2 (  30 )                                        /*  90 先画面ID     */
 , HREF         VARCHAR2 ( 256 )                                        /* 100 ﾘﾝｸ先URL     */
 , TARGET       VARCHAR2 (  10 )                                        /* 110 ﾀｰｹﾞｯﾄ       */
 , P_KEYS       VARCHAR2 ( 500 )                                        /* 120 引数ｷｰ       */
 , P_VALS       VARCHAR2 ( 500 )                                        /* 130 引数値       */
 , COMMAND      VARCHAR2 (  30 )                                        /* 140 ｺﾏﾝﾄﾞ        */
 , LBLCD        VARCHAR2 (  60 )                                        /* 150 ﾗﾍﾞﾙｺｰﾄﾞ     */
 , MSGCD        VARCHAR2 (  20 )                                        /* 160 ﾒｯｾｰｼﾞID     */
 , ONCLICK      VARCHAR2 ( 200 )                                        /* 170 ｲﾍﾞﾝﾄ        */
 , ROLES        VARCHAR2 ( 500 )                                        /* 180 ﾛｰﾙｽﾞ        */
 , FGOMIT       VARCHAR2 (   1 )        DEFAULT '0' NOT NULL            /* 190 除外ﾌﾗｸﾞ     */
 , UNIQ         NUMBER   (   9 )        DEFAULT 0   NOT NULL            /* 800 ﾕﾆｰｸｷｰ       */
 , FGJ          VARCHAR2 (   1 )        DEFAULT '1' NOT NULL            /* 810 状態ﾌﾗｸﾞ     */
 , DYSET        VARCHAR2 (  14 )                                        /* 820 登録日時     */
 , PGSET        VARCHAR2 (  10 )                                        /* 830 作成PG       */
 , PGPSET       VARCHAR2 (  10 )                                        /* 840 作成親PG     */
 , USRSET       VARCHAR2 (  10 )                                        /* 850 作成社員     */
 , DYUPD        VARCHAR2 (  14 )                                        /* 860 更新日時     */
 , PGUPD        VARCHAR2 (  10 )                                        /* 870 更新PG       */
 , PGPUPD       VARCHAR2 (  10 )                                        /* 880 更新親PG     */
 , USRUPD       VARCHAR2 (  10 )                                        /* 890 更新者       */
)
TABLESPACE GETBL01
STORAGE( INITIAL 16K NEXT 16K PCTINCREASE 0 );

CREATE SEQUENCE GF72S00 
  INCREMENT BY 1 START WITH 1 MAXVALUE 999999999 CYCLE NOCACHE;

CREATE OR REPLACE TRIGGER GF72T00 
  BEFORE INSERT ON GF72
  FOR EACH ROW 
  BEGIN 
    SELECT GF72S00.NEXTVAL INTO :NEW.UNIQ FROM DUAL; 
  END; 
/

==> openGion_dev_5.6.9.0.zip: opengion/uap/webapps/gf/db/oracle/sql/install/01_TABLE/GF72S.sql <==
/****************************************************************************/
/* GF72 ( 登録ﾎﾞﾀﾝ状態ﾃｰﾌﾞﾙ )                                               */
/*                                                                          */
/* Created : 2013/09/30 18:24:49                                            */
/****************************************************************************/
CREATE TABLE GF72 (
   SYSTEM_ID    VARCHAR2 (  10 )                    NOT NULL            /*  10 ｼｽﾃﾑID       */
 , TBLSYU       VARCHAR2 (   1 )                    NOT NULL            /*  20 ﾃｰﾌﾞﾙ種別    */
 , ADDRESS      VARCHAR2 ( 256 )                                        /*  30 ｱﾄﾞﾚｽ        */
 , FILENAME     VARCHAR2 (  60 )                                        /*  40 ﾌｧｲﾙ名       */
 , FILEPATH     VARCHAR2 ( 256 )                                        /*  50 ﾌｧｲﾙﾊﾟｽ      */
 , MODIFIED     VARCHAR2 (  14 )                                        /*  60 最終更新日   */
 , TAGNAME      VARCHAR2 (  30 )                                        /*  80 ﾀｸﾞ名称      */
 , TO_GAMENID   VARCHAR2 (  30 )                                        /*  90 先画面ID     */
 , HREF         VARCHAR2 ( 256 )                                        /* 100 ﾘﾝｸ先URL     */
 , TARGET       VARCHAR2 (  30 )                    NOT NULL            /* 110 ﾀｰｹﾞｯﾄ       */
 , P_KEYS       VARCHAR2 ( 500 )                                        /* 120 引数ｷｰ       */
 , P_VALS       VARCHAR2 ( 500 )                                        /* 130 引数値       */
 , COMMAND      VARCHAR2 (  30 )                                        /* 140 ｺﾏﾝﾄﾞ        */
 , LBLCD        VARCHAR2 (  60 )                                        /* 150 ﾗﾍﾞﾙｺｰﾄﾞ     */
 , MSGCD        VARCHAR2 (  20 )                                        /* 160 ﾒｯｾｰｼﾞID     */
 , ONCLICK      VARCHAR2 ( 200 )                                        /* 170 ｲﾍﾞﾝﾄ        */
 , ROLES        VARCHAR2 ( 500 )                                        /* 180 ﾛｰﾙｽﾞ        */
 , FGOMIT       VARCHAR2 (   1 )        DEFAULT '0' NOT NULL            /* 190 除外ﾌﾗｸﾞ     */
 , UNIQ         NUMBER   (   9 )        DEFAULT 0   NOT NULL            /* 800 ﾕﾆｰｸｷｰ       */
 , FGJ          VARCHAR2 (   1 )        DEFAULT '1' NOT NULL            /* 810 状態ﾌﾗｸﾞ     */
 , DYSET        VARCHAR2 (  14 )                                        /* 820 登録日時     */
 , PGSET        VARCHAR2 (  10 )                                        /* 830 作成PG       */
 , PGPSET       VARCHAR2 (  10 )                                        /* 840 作成親PG     */
 , USRSET       VARCHAR2 (  10 )                                        /* 850 作成社員     */
 , DYUPD        VARCHAR2 (  14 )                                        /* 860 更新日時     */
 , PGUPD        VARCHAR2 (  10 )                                        /* 870 更新PG       */
 , PGPUPD       VARCHAR2 (  10 )                                        /* 880 更新親PG     */
 , USRUPD       VARCHAR2 (  10 )                                        /* 890 更新者       */
)
TABLESPACE GETBL01
STORAGE( INITIAL 16K NEXT 16K PCTINCREASE 0 );

CREATE SEQUENCE GF72S00 
  INCREMENT BY 1 START WITH 1 MAXVALUE 999999999 CYCLE NOCACHE;

CREATE OR REPLACE TRIGGER GF72T00 
  BEFORE INSERT ON GF72
  FOR EACH ROW 
  BEGIN 
    SELECT GF72S00.NEXTVAL INTO :NEW.UNIQ FROM DUAL; 
  END; 
/
